<?php

namespace app\api\logic\Code;

use app\common\model\Code\CodeModuleCategory as ModelCodeModuleCategory;
use app\common\model\Token as ModelToken;
use app\common\exception\Tool;


class CodeModuleCategory
{
    /**
     * 构建客户代码类目初始审核状态
     * 
     * @param int $library_type 库类型
     * @return int 审核状态
     * @date 2023-07-19
     * @author xjh
     * @since 1.0.0
     */
    public static function buildCodeModuleCategoryAudit(int $library_type): int
    {
        if ($library_type == ModelCodeModuleCategory::LIBRARY_PRIVATE) {
            return ModelCodeModuleCategory::AUDIT_PASS;
        } else {
            return ModelCodeModuleCategory::AUDIT_FAILED;
        }
    }

    /**
     * 代码类目新增验证
     * 
     * @param array $params 新增代码类目的参数
     * @return array
     * @date 2023-07-14
     * @author xjh
     * @since 1.0.0
     */
    public static function validateAddCodeModuleCategory(array $params): void
    {
        if ($params['code_module_category_parent_guid'] != ModelCodeModuleCategory::MASTER_DEFAULT) {
            $category = ModelCodeModuleCategory::find($params['code_module_category_parent_guid']);
            if ($category) {
                if ($category->customer_guid != ModelToken::getCurrentCustomer()->customer_guid) {
                    throwErrorMsg("所选的上级类目不属于当前客户!");
                }
            } else {
                throwErrorMsg("所选的上级类目不存在!");
            }
        }
        if (!in_array($params['code_module_category_library_type'], [ModelCodeModuleCategory::LIBRARY_COMMON, ModelCodeModuleCategory::LIBRARY_PRIVATE])) {
            throwErrorMsg("新增类目的所属库类型异常!");
        }
    }

    /**
     * 代码类目编辑验证
     * 
     * @param string $code_module_category_guid 类目guid
     * @return array
     * @date 2023-07-14
     * @author xjh
     * @since 1.0.0
     */
    public static function validateEditCodeModuleCategory(string $code_module_category_guid): void
    {
        $category = ModelCodeModuleCategory::find($code_module_category_guid);
        if (!$category) {
            throwErrorMsg("所编辑的类目不存在!");
        }
        if ($category->customer_guid != ModelToken::getCurrentCustomer()->customer_guid) {
            throwErrorMsg("所编辑的类目不属于当前客户!");
        }
    }
}